Learning outcomes

The skills and methods taught in this focused EMBL-EBI course apply broadly across infectious disease epidemiology, from outbreak response to routine surveillance of endemic diseases.

This half-day course focuses on the core methods for real-time analysis of infectious disease surveillance data, specifically Rt estimation and nowcasting.

Session 1: \(R_t\) estimation and the renewal equation

  • understanding of the reproduction number and challenges in its estimation
  • understanding of the renewal equation as an epidemiological model for infection generation
  • familiarity with the generation time as a particular type of delay distribution
  • understanding of the role of the generative model in the estimation of \(R_t\)
  • familiarity with geometric random walk models for smoothing \(R_t\) estimates

Session 2: Nowcasting concepts

  • understanding of nowcasting as a particular right truncation problem
  • understanding of the difference between report date and event dates
  • familiarity with simple nowcasting using known delay distributions
  • familiarity with improving the model of the data generating process with geometric random walk models to improve nowcast performance in some circumstances

Session 3: Joint nowcasting with unknown delays

  • understanding of the reporting triangle structure for epidemiological surveillance data
  • understanding of the benefits of joint estimation of delay distributions and nowcasts
  • understanding of population-level modelling with observation error
  • understanding of the link between Rt estimation and nowcasting

Technical skills

  • familiarity with using Stan to estimate parameters of epidemiological models
  • familiarity with interpreting posterior distributions and quantifying parameter uncertainty
  • understanding of the role of the generative model in real-time analysis
  • familiarity with time delays and reporting patterns in epidemiological surveillance data